@@ -1,10 +1,7 @@
 import itertools
-import os
 from collections.abc import Mapping, Sequence
 from typing import Any, Union
 
-from envsubst import envsubst
-
 from komposer.exceptions import (
     ExtraManifestInvalidYamlError,
     ExtraManifestMissingMetadataError,
@@ -15,13 +12,6 @@ from komposer.types.cli import Context
 from komposer.utils import load_yaml
 
 
-def _komposer_service_prefix_value(context: Context) -> str:
-    return context.manifest_prefix
-
-
-komposer_env_variables_map = {"KOMPOSER_SERVICE_PREFIX": _komposer_service_prefix_value}
-
-
 def update_item_metadata_labels(item: Mapping, labels: Mapping) -> None:
     item["metadata"].setdefault("labels", {}).update(labels)
 
@@ -42,16 +32,6 @@ def update_item_env_configmapkeyref_name(item: Mapping, manifest_prefix: str) ->
         config_map_key_ref["name"] = f"{manifest_prefix}-{config_map_key_ref['name']}"
 
 
-def replace_env_variables(context: Context, extra_manifest_str: str) -> str:
-    for env_name, env_fn in komposer_env_variables_map.items():
-        env_value = env_fn(context)
-        os.environ[env_name] = env_value
-
-        extra_manifest_str = envsubst(extra_manifest_str)
-
-    return extra_manifest_str
-
-
 def get_items_from_extra_manifest(extra_manifest_raw: Union[Mapping, Sequence]) -> list[dict]:
     # Returns empty list if null
     if extra_manifest_raw is None:
@@ -88,22 +68,30 @@ def ensure_metadata_is_present(extra_manifest_items: Sequence[Mapping[str, Any]]
             )
 
 
-def load_extra_manifest(context: Context) -> list[dict]:
+def load_extra_manifests(context: Context) -> list[dict]:
     # Skip if no extra manifest
-    if context.extra_manifest_path is None:
+    if context.extra_manifest_paths is None:
         return []
 
     # Load manifest
-    extra_manifest_str = context.extra_manifest_path.read_text()
-
-    # Replace KOMPOSER_* env variables
-    extra_manifest_str = replace_env_variables(context, extra_manifest_str)
+    extra_manifests_str = (
+        extra_manifest_path.read_text() for extra_manifest_path in context.extra_manifest_paths
+    )
 
     # Parse manifest
-    extra_manifest_raw = load_yaml(extra_manifest_str)
+    extra_manifests_raw = (
+        load_yaml(extra_manifest_str) for extra_manifest_str in extra_manifests_str
+    )
 
     # Just validate that the format of the file
-    extra_manifest_items = get_items_from_extra_manifest(extra_manifest_raw)
+    extra_manifest_items = list(
+        itertools.chain(
+            *(
+                get_items_from_extra_manifest(extra_manifest_raw)
+                for extra_manifest_raw in extra_manifests_raw
+            )
+        )
+    )
 
     ensure_metadata_is_present(extra_manifest_items)
 
