@@ -26,6 +26,7 @@ class DeploymentContext(ImmutableBaseModel):
 
 class IngressContext(ImmutableBaseModel):
     tls_path: Optional[Path] = None
+    domain: str
 
     @property
     def tls(self) -> Optional[Any]:
@@ -39,7 +40,7 @@ class Context(ImmutableBaseModel):
     default_image: str
     project_name: Optional[str] = None
     ingress_for_service: Optional[str] = None
-    extra_manifest_path: Optional[Path] = None
+    extra_manifest_paths: list[Path]
     deployment: DeploymentContext
     ingress: IngressContext
 
